# 'Polemarch' documentation

# Welcome to Polemarch’s documentation!

Polemarch is a service for infrastructure orchestration based on ansible. Simple WEB gui for infrastructure orchestration using ansible playbooks.

You could find latest releases there. Also you could find source code in official repository.

Contact us on any questions or report bugs.

Official site: https://polemarch.org/

We also help you via:

Twitter - we post information about new releases and new features

Slack - support channel

Stack Overflow - tag for questions about our application on Stack Overflow

Contents:

- Installation
  - Install from PyPI
  - Quickstart
  - Backup
  - Update
  - Update from any old version
  - Migrate
  - Create superuser
  - Change password
- Configuration manual
  - Introduction
  - Polemarch clustering overview
  - Main settings
  - Database settings
  - Cache settings
  - Locks settings
  - Session cache settings
  - Rpc settings
  - Worker settings
  - Web settings
  - Git settings
  - Production web settings
  - Configuration options
  - Installation of additional packages to Polemarch
- GUI workflow
  - Welcome to Polemarch GUI
  - Before you start
  - Projects
  - Project variables
  - Module execution
  - Template
  - Periodic tasks
  - Inventory
  - Group
  - Host
  - Variables for inventory, group, host
  - Import inventory
  - .polemarch.yaml
  - Community project samples
  - Hooks
  - Users
- API
  - Structure
- How to participate
- VST Consulting contributor agreement
  - 1. Definitions
  - 2. Copyright Assignment, License and Waiver
  - 3. Patent License
  - 4. Your Representation and Warranties.
  - 5. Intellectual Property
  - Miscellaneous